# Buzak Meme
Fetch and manage memes from [szkola.buz.info.pl](https://szkola.buz.info.pl) with ease

![Example Buzak Meme](https://szkola.buz.info.pl/graf/linux16.jpg "Example Buzak Meme")
***Example Buzak Meme***

## Installation
```bash
pip install buzak-meme
```

## Usage
### Fetching a random Meme from [szkola.buz.info.pl](https://szkola.buz.info.pl)
```python
from buzak_meme import get_random_meme

meme = get_random_meme() # Return Meme

print(meme) # Does not actually fetch the image, only prepares the image link
```

### Saving a meme to disk
```python
from buzak_meme import get_random_meme

meme = get_random_meme() 

meme.save_meme("./buzak-meme.jpg") # Fetches and saves image, might raise MemeNotFoundError. All memes are JPG always
```

### Getting a meme's raw bytes
```python
from buzak_meme import get_random_meme

meme = get_random_meme() 

print(meme.fetch_image()[:10], "...") # Fetches and loads the image bytes, might raise MemeNotFoundError. All memes are JPG always. this line prints only the first 10 bytes for testing
```

# Conclusion
Buzak Meme (`buzak_meme`) is an easy way to fetch and manage memes from szkola.buz.info.pl

# Credit
All memes are the intellectual property of the owners of [szkola.buz.info.pl](https://szkola.buz.info.pl), or accredited authors on the page. This code is provided as-is only.
